Versions
========

0.2.0 
=======

_Release date: 2022-04-12_

- Support python3.10
- Update pytest dependency versions
- Cover testing section

0.1.10
=======

_Release date: 2021-10-10_

- Cover skipped result with emoji

0.1.9
=======

_Release date: 2021-06-06_

- Declare used tools

0.1.8
=======

_Release date: 2021-06-06_

- Support python 3.9

0.1.7
=======

_Release date: 2020-10-03_

- Bump package versions

0.1.6
=======

_Release date: 2020-10-03_

- Include package unit tests
- Move images into media folder
- Introduce interrogate docstring coverage tool for static analysis
- Use 100 line of code
- Rework contributing guide

0.1.5
========

_Release date: 2020-04-23_

- Fix organisation badges
- Track count of PYPI downloads

0.1.4
========

_Release date: 2020-02-19_

- Package 0.1.4 version
- Specify runner command in readme file
- Introduce short runner flag '--eo'

0.1.3
========

_Release date: 2020-02-14_

- Create installable package via pip

0.1.2
========

_Release date: 2020-02-14_

- Create plugin unittests

0.1.1
========

_Release date: 2020-02-13_

- Introduce PYPI package

0.1.0
========

_Release date: 2020-02-12_

- Distribute initial package version
